@@ -1,4 +1,4 @@
-# Copyright (C) 2021-2022 Koen Derks
+# Copyright (C) 2021-2023 Koen Derks
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 #' @description This function draws Chladni figures on a canvas and subsequently warps the domain under these figures.
 #'
 #' @usage canvas_chladni(colors, waves = 5, warp = 0, resolution = 500,
-#'                angles = NULL, distances = NULL)
+#'                angles = NULL, distances = NULL, flatten = FALSE)
 #'
 #' @param colors      a string or character vector specifying the color(s) used for the artwork.
 #' @param waves       a character specifying the number of randomly sampled waves, or an integer vector of waves to be summed.
@@ -26,6 +26,7 @@
 #' @param warp        a numeric value specifying the maximum warping distance for each point. If \code{warp = 0} (the default), no warping is performed.
 #' @param angles      optional, a resolution x resolution matrix containing the angles for the warp, or a character indicating the type of noise to use (\code{svm}, \code{knn}, \code{rf}, \code{perlin}, \code{cubic}, \code{simplex}, or \code{worley}). If \code{NULL} (the default), the noise type is chosen randomly.
 #' @param distances   optional, a resolution x resolution matrix containing the distances for the warp, or a character indicating the type of noise to use (\code{svm}, \code{knn}, \code{rf}, \code{perlin}, \code{cubic}, \code{simplex}, or \code{worley}). If \code{NULL} (the default), the noise type is chosen randomly.
+#' @param flatten     logical, should colors be flattened after being assigned to a point.
 #'
 #' @return A \code{ggplot} object containing the artwork.
 #'
@@ -49,7 +50,7 @@
 #' @export
 
 canvas_chladni <- function(colors, waves = 5, warp = 0, resolution = 500,
-                           angles = NULL, distances = NULL) {
+                           angles = NULL, distances = NULL, flatten = FALSE) {
   .checkUserInput(resolution = resolution)
   if (length(waves) == 1) {
     waves <- sample(1:50, size = waves, replace = TRUE)
@@ -63,6 +64,9 @@ canvas_chladni <- function(colors, waves = 5, warp = 0, resolution = 500,
     inputCanvas <- as.matrix(canvas)
   }
   full_canvas <- data.frame(x = canvas[, 1], y = canvas[, 2], z = iterate_chladni(x = inputCanvas[, 1], y = inputCanvas[, 2], waves))
+  if (flatten) {
+    full_canvas$z <- round(full_canvas$z, 0)
+  }
   artwork <- ggplot2::ggplot(data = full_canvas, mapping = ggplot2::aes(x = x, y = y, fill = z)) +
     ggplot2::geom_raster(interpolate = TRUE) +
     ggplot2::scale_fill_gradientn(colours = colors)
