@@ -1,4 +1,4 @@
-# Copyright (C) 2021-2022 Koen Derks
+# Copyright (C) 2021-2023 Koen Derks
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -59,7 +59,7 @@ canvas_diamonds <- function(colors, background = "#fafafa", col.line = "black",
   locs <- data.frame(x = x, bottom = bottom, top = top)
   palette <- NULL
   full_canvas <- data.frame(x = numeric(), y = numeric(), type = numeric())
-  for (j in 1:nrow(locs)) {
+  for (j in seq_len(nrow(locs))) {
     rs <- ceiling((top[j] - bottom[j]) / (radius * 2)) # required squares
     for (i in 1:rs) {
       xvec <- c(locs$x[j], locs$x[j] + radius, locs$x[j], locs$x[j] - radius, locs$x[j])
@@ -78,12 +78,12 @@ canvas_diamonds <- function(colors, background = "#fafafa", col.line = "black",
     ggplot2::geom_curve(
       data = data.frame(x = 0, y = sample(0:resolution / 2, size = 1), xend = resolution, yend = sample((resolution / 2):resolution, size = 1), type = 999),
       mapping = ggplot2::aes(x = x, y = y, xend = xend, yend = yend),
-      colour = col.line, size = stats::runif(1, 5, 15), curvature = stats::runif(1, 0, 0.5)
+      colour = col.line, linewidth = stats::runif(1, 5, 15), curvature = stats::runif(1, 0, 0.5)
     ) +
     ggplot2::geom_curve(
       data = data.frame(x = 0, y = sample((resolution / 2):resolution, size = 1), xend = resolution, yend = sample(0:resolution / 2, size = 1), type = 999),
       mapping = ggplot2::aes(x = x, y = y, xend = xend, yend = yend),
-      colour = col.line, size = stats::runif(1, 5, 15), curvature = stats::runif(1, -0.5, 0)
+      colour = col.line, linewidth = stats::runif(1, 5, 15), curvature = stats::runif(1, -0.5, 0)
     ) +
     ggplot2::geom_polygon(fill = full_canvas$col, color = NA, alpha = alpha) +
     ggplot2::scale_fill_manual(values = palette)
