@@ -1,4 +1,4 @@
-# Copyright (C) 2021-2022 Koen Derks
+# Copyright (C) 2021-2023 Koen Derks
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -15,14 +15,17 @@
 
 #' Draw the Mandelbrot Set
 #'
-#' @description This function draws the Mandelbrot set on the canvas.
+#' @description This function draws the Mandelbrot set and other related fractal sets on the canvas.
 #'
-#' @usage canvas_mandelbrot(colors, iterations = 100, zoom = 1, left = -1.7, right = -0.2,
-#'                    bottom = -0.2999, top = 0.8001, resolution = 500)
+#' @usage canvas_mandelbrot(colors, iterations = 100, zoom = 1,
+#'                    set = c("mandelbrot", "multibrot", "julia", "ship"),
+#'                    left = -2.16, right = 1.16, bottom = -1.66, top = 1.66,
+#'                    resolution = 500)
 #'
 #' @param colors      a string or character vector specifying the color(s) used for the artwork.
 #' @param iterations  a positive integer specifying the number of iterations of the algorithm.
 #' @param zoom        a positive value specifying the amount of zoom to apply.
+#' @param set         a character indicating which fractal set to draw. Possible options are \code{mandelbrot} for the Mandelbrot set, \code{multibrot} for variations of the Mandelbrot set (aka the Multibrot sets), \code{julia} for the Julia set and \code{ship} for the Burning ship set.
 #' @param left        a value specifying the minimum location on the x-axis.
 #' @param right       a value specifying the maximum location on the x-axis.
 #' @param bottom      a value specifying the minimum location on the y-axis.
@@ -41,14 +44,18 @@
 #'
 #' @examples
 #' \donttest{
-#' canvas_mandelbrot(colors = colorPalette("tuscany1"))
+#' canvas_mandelbrot(colors = colorPalette("tuscany1"), set = "mandelbrot")
+#' canvas_mandelbrot(colors = colorPalette("flag"), set = "julia", zoom = 2)
 #' }
 #'
 #' @export
 
-canvas_mandelbrot <- function(colors, iterations = 100, zoom = 1, left = -1.7, right = -0.2,
-                              bottom = -0.2999, top = 0.8001, resolution = 500) {
+canvas_mandelbrot <- function(colors, iterations = 100, zoom = 1,
+                              set = c("mandelbrot", "multibrot", "julia", "ship"),
+                              left = -2.16, right = 1.16, bottom = -1.66, top = 1.66,
+                              resolution = 500) {
   .checkUserInput(resolution = resolution, iterations = iterations)
+  set <- match.arg(set)
   if (zoom > 1) {
     for (i in 1:(zoom - 1)) {
       xmin_tmp <- left
@@ -63,15 +70,26 @@ canvas_mandelbrot <- function(colors, iterations = 100, zoom = 1, left = -1.7, r
   }
   x <- seq(left, right, length.out = resolution)
   y <- seq(bottom, top, length.out = resolution)
-  c <- outer(x, y * 1i, FUN = "+")
-  z <- matrix(0, nrow = length(x), ncol = length(y))
+  mk <- sample(3:5, size = 1)
+  if (set != "julia") {
+    z <- matrix(0, nrow = length(x), ncol = length(y))
+    c <- outer(x, y * 1i, FUN = "+")
+  } else {
+    z <- outer(x, y * 1i, FUN = "+")
+    c <- -0.4 + 0.6 * 1i
+  }
   canvas <- matrix(0, nrow = length(x), ncol = length(y))
   for (rep in 1:iterations) {
     index <- which(Mod(z) < 2)
-    z[index] <- z[index]^2 + c[index]
+    z[index] <- switch(set,
+      "mandelbrot" = z[index]^2 + c[index],
+      "multibrot" = z[index]^mk + c[index],
+      "julia" = z[index]^2 + c,
+      "ship" = (abs(Re(z[index])) + abs(Im(z[index])) * 1i)^2 + c[index]
+    )
     canvas[index] <- canvas[index] + 1
   }
-  full_canvas <- .unraster(canvas, names = c("x", "y", "z")) # Convert 2D matrix to data frame
+  full_canvas <- .unraster(canvas, names = c("x", "y", "z"))
   artwork <- ggplot2::ggplot(data = full_canvas, ggplot2::aes(x = x, y = y, fill = z)) +
     ggplot2::geom_raster(interpolate = TRUE, alpha = 0.9) +
     ggplot2::xlim(c(0, resolution + 1)) +
