@@ -1,4 +1,4 @@
-# Copyright (C) 2021-2022 Koen Derks
+# Copyright (C) 2021-2023 Koen Derks
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -72,14 +72,14 @@ canvas_recaman <- function(colors, background = "#fafafa", iterations = 100, sta
     xend <- x[-1]
     x <- x[-length(x)]
   }
-  canvas <- data.frame(z = 1:length(x), x = x, xend = xend)
+  canvas <- data.frame(z = seq_along(x), x = x, xend = xend)
   canvas$y <- x * sin(angle %% 360)
   canvas$yend <- canvas$y[match(canvas$xend, canvas$x)]
   minx <- apply(canvas[, 2:3], 1, min, na.rm = TRUE)
   maxx <- apply(canvas[, 2:3], 1, max, na.rm = TRUE)
   miny <- apply(canvas[, 4:5], 1, min, na.rm = TRUE)
   maxy <- apply(canvas[, 4:5], 1, max, na.rm = TRUE)
-  for (i in 1:nrow(canvas)) {
+  for (i in seq_len(nrow(canvas))) {
     if (i %% 2 == 1) {
       canvas[i, 2:5] <- c(minx[i], maxx[i], miny[i], maxy[i])
     } else {
@@ -92,7 +92,7 @@ canvas_recaman <- function(colors, background = "#fafafa", iterations = 100, sta
   artwork <- ggplot2::ggplot() +
     ggplot2::geom_curve(
       mapping = ggplot2::aes(x = x, y = y, xend = xend, yend = yend, color = z),
-      data = canvas, curvature = curvature, ncp = 25, size = size
+      data = canvas, curvature = curvature, ncp = 25, linewidth = size
     ) +
     ggplot2::scale_color_gradientn(colors = colors)
   artwork <- theme_canvas(artwork, background = background)
