@@ -1,4 +1,4 @@
-# Copyright (C) 2021-2022 Koen Derks
+# Copyright (C) 2021-2023 Koen Derks
 
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -91,7 +91,7 @@
 
 # This function turns a matrix into a data frame with columns x, y, and z
 .unraster <- function(x, names) {
-  newx <- data.frame(x = rep(1:ncol(x), times = ncol(x)), y = rep(1:nrow(x), each = nrow(x)), z = c(x))
+  newx <- data.frame(x = rep(seq_len(ncol(x)), times = ncol(x)), y = rep(seq_len(nrow(x)), each = nrow(x)), z = c(x))
   colnames(newx) <- names
   return(newx)
 }
